@@ -24,27 +24,22 @@ __all__ = [
     'get_debhelper_compat_level',
 ]
 
-from dataclasses import dataclass
 import os
-from typing import Optional, Union, Dict, List
-
-from debian.deb822 import Deb822
+from dataclasses import dataclass
+from typing import Dict, List, Optional, Union
 
 from debian.changelog import Version
+from debian.deb822 import Deb822
 
-from .control import (
-    ensure_minimum_version,
-    get_relation,
-    parse_relations,
-    ControlEditor,
-)
+from .control import (ControlEditor, ensure_minimum_version, get_relation,
+                      parse_relations)
 from .reformatting import Editor
 
 
 def ensure_minimum_debhelper_version(
         source: Union[Deb822, Dict[str, str]],
         minimum_version: Union[str, Version]) -> bool:
-    """Ensure that the pakcage is at least using version x of debhelper.
+    """Ensure that the package is at least using version x of debhelper.
 
     This is a dedicated helper, since debhelper can now also be pulled in
     with a debhelper-compat dependency.
@@ -229,7 +224,7 @@ class MaintscriptEditor(Editor[List[Union[str, MaintscriptEntry]], str]):
         super().__init__(
             path=path, allow_reformatting=allow_reformatting)
 
-    def _nonexistant(self):
+    def _nonexistent(self):
         return None
 
     def _parse(self, content):
