@@ -18,13 +18,12 @@
 """Utility functions for editing patches under debian/patches/.
 """
 
-from collections import namedtuple
 import os
+from collections import namedtuple
 from typing import Iterator, List, Optional
 
 from .reformatting import Editor
 
-
 DEFAULT_DEBIAN_PATCHES_DIR = 'debian/patches'
 
 
@@ -105,7 +104,7 @@ class QuiltSeriesEditor(Editor[List[QuiltSeriesEntry], bytes]):
     def _parse(self, content):
         return list(read_quilt_series(content.splitlines(True)))
 
-    def _nonexistant(self):
+    def _nonexistent(self):
         return None
 
     def _format(self, parsed):
